import datetime
from django.db import models
from django.utils import timezone

class Category(models.Model):
    name = models.CharField(max_length=30)

    def __str__(self):
        return self.name

class Question(models.Model):
    class Meta:
        permissions = (
            ('can_think', 'very intelligent people'),)
    question_text = models.CharField(max_length=200)
    pub_date = models.DateTimeField('date published')
    category_id = models.ForeignKey(Category, on_delete=models.SET_NULL, default=None, null=True)
    def __str__(self):
        return self.question_text
    
    def was_published_recently(self):
        now = timezone.now()
        return now - datetime.timedelta(days=1) <= self.pub_date <= now

    def save(self, *args, **kwargs):
        if not self.pub_date:
            self.pub_date = datetime.datetime.now()
        super().save(*args, **kwargs)

class Choice(models.Model):
    question = models.ForeignKey(Question, on_delete=models.CASCADE)
    choice_text = models.CharField(max_length=200)
    votes = models.IntegerField(default=0)
    
    def has_votes(self):
        if self.votes > 0:
            return True
        return False

    def __str__(self):
        return self.choice_text

class QuestionChoice(models.Model):
    """ vote also for the question ! """
    question = models.ForeignKey(Question, on_delete=models.CASCADE)
    score = models.IntegerField(default=0)
    def __str__(self):
        return str(self.score)

