import datetime 

from django.test import TestCase
from django.utils import timezone
from django.urls import reverse

from . import models 

# ----------------- Models tests --------------------------------

class QuestionModelTests(TestCase):
    def test_was_published_recently_with_future_question(self):
        """
        was_published_recently() returns False for questions whose pub_date
        is in the future.
        """
        time = timezone.now() + datetime.timedelta(days=30)
        future_question = models.Question(pub_date=time)
        self.assertIs(future_question.was_published_recently(), False)

    def test_was_published_recently_with_old_question(self):
        """
        was_published_recently() returns False for questoins whose pub_date
        is older than 1 day. 
        """
        time = timezone.now() - datetime.timedelta(days=1, seconds=1)
        old_question = models.Question(pub_date=time)
        self.assertIs(old_question.was_published_recently(), False)

    def test_was_published_recently_with_recent_question(self):
        """
        was_published_recently() returns True for question whose pub_date 
        is within the last day.
        """
        time = timezone.now() - datetime.timedelta(
            hours=23, minutes=59, seconds=59)
        recent_question = models.Question(pub_date=time)
        self.assertIs(recent_question.was_published_recently(), True)

def create_question(question_text):
    """ create a question """
    return models.Question.objects.create(question_text=question_text)

class IndexViewTests(TestCase):
    def test_no_questions(self):
        response = self.client.get(reverse('polls:index'))
        self.assertEqual(response.status_code, 200)
        self.assertQuerysetEqual(response.context['latest_question_list'], [])

    def test_have_questions(self): # pourquoi celui-ci ne passe pas ?
        #question = create_question(question_text="Le test est-il good ?")
        models.Question.objects.create(question_text='Le test est-il good ?')
        models.Question.objects.create(question_text='Le test est-il good ?')
        models.Question.objects.create(question_text='Le test est-il good ?')
        all_ = models.Question.objects.all()
        print('all:{}'.format(all_))
        response = self.client.get(reverse('polls:index'))
        print('response.context:{}'.format(response.context))
        self.assertEqual(response.status_code, 200)
        self.assertQuerysetEqual(
                response.context['latest_question_list'],
                ['<Question: Le test est-il good ?>'])

    def test_have_categories(self):
        created = models.Category.objects.create(name='Categorie de test')
        response = self.client.get(reverse('polls:index'))
        self.assertEqual(response.status_code, 200)
        self.assertQuerysetEqual(
                response.context['category_list'],
                ['<Category: Categorie de test>'])

